<template>
  <InfiniteLoading scrollViewClassName="common-infinite-scroll-list" v-bind="infiniteLoadingProps">
    <template #renderItem="{ item }">
      <ResourceCard
        :title="item.title"
        :src="item.avatarUrl"
        :name="item.contact"
        :jobTitle="item.jobTitle"
        :time="item.lastShelfTime"
        :resourceCount="item.resourceCount"
        :intendedDeliveryCities="item.intendedDeliveryCities"
        @click="handleClick(item)"
        :showActionBtn="false"
      >
      </ResourceCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { useInfiniteLoading } from '@12333/hooks';
import * as resourceServices from '@12333/services/api/Resource';
import { OrderInputType } from '@12333/constants';
import Taro from '@tarojs/taro';

type Props = {
  userId?: string;
};

const props = withDefaults(defineProps<Props>(), {});

const queryState = reactive({
  userId: props.userId,
});

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.GetFrontResourceListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [
          { property: 'isRecommend', order: OrderInputType.Desc },
          { property: 'lastShelfTime', order: OrderInputType.Desc },
        ],
      },
      userId: queryState.userId,
    };

    return resourceServices.getFrontResourceList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['resourceServices/getFrontResourceList', queryState],
  }
);

function handleClick(item: API.GetFrontResourceList) {
  Taro.navigateTo({
    url: `${RouterPath.resourceDetail}?id=${item.id}`,
  });
}
</script>
